@@ -1,7 +1,8 @@
 #' @import parmigene
+#' @importFrom infotheo discretize mutinformation
 NULL
 
-#' Mutual information network connection matrix generation (mrnet algorithm) using the parmigene package
+#' Mutual information network connection matrix generation (mrnet algorithm) using the parmigene package. Mutual information calculated with infotheo package.
 #' 
 #' @param dataMatrix data matrix with first column being the sample ID
 #' @param threshold the number of edges to draw for each subpopulation mutual information network
@@ -10,7 +11,9 @@ NULL
 
 MINetwork_matrix_topEdges<-function(dataMatrix, threshold){
   
-  dataMatrix_mi<-knnmi.all(t(dataMatrix))
+  dat<-discretize(dataMatrix)
+  dataMatrix_mi<-mutinformation(dat, method="emp")
+  
   dataMatrix_net<-mrnet(dataMatrix_mi)
   
   filterLevel<-dataMatrix_net[order(dataMatrix_net, decreasing=TRUE)][threshold]
